<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
session_start();

// Verificar si el usuario está autenticado y tiene privilegios
if (!isset($_SESSION['usuario_id']) || $_SESSION['usuario_rol'] !== 'admin') {
    header("Location: login.php"); // Redirigir al login si no tiene privilegios
    exit();
}

include '../../includes/db_connect.php';

// Procesar el formulario para crear una nueva rifa
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['crear_rifa'])) {
    $nombre_rifa = $_POST['nombre_rifa'];
    $premio = $_POST['premio'];
    $cantidad_numeros = intval($_POST['cantidad_numeros']);
    $precio_unitario = floatval($_POST['precio_unitario']);
    $fecha_sorteo = $_POST['fecha_sorteo'];

    // Procesar la imagen
    if (isset($_FILES['imagen']) && $_FILES['imagen']['error'] === UPLOAD_ERR_OK) {
        $imagen_nombre = basename($_FILES['imagen']['name']); // Nombre del archivo
        $imagen_tmp = $_FILES['imagen']['tmp_name']; // Ruta temporal del archivo
        $imagen_ruta = "../../assets/img/rifas/" . $imagen_nombre; // Ruta donde se guardará la imagen

        // Mover la imagen a la carpeta de destino
        if (move_uploaded_file($imagen_tmp, "" . $imagen_ruta)) {
            // Insertar la nueva rifa en la base de datos
            $sql = "INSERT INTO rifas_activas (nombre_rifa, premio, cantidad_numeros, precio_unitario, fecha_sorteo, imagen) 
                    VALUES (?, ?, ?, ?, ?, ?)";
            $stmt = $conn->prepare($sql);
            if (!$stmt) {
                die("Error en la preparación de la consulta: " . $conn->error);
            }
            $stmt->bind_param("ssidss", $nombre_rifa, $premio, $cantidad_numeros, $precio_unitario, $fecha_sorteo, $imagen_ruta);

            if ($stmt->execute()) {
                $mensaje = "Rifa creada con éxito.";
            } else {
                $error = "Error al crear la rifa: " . $stmt->error;
            }

            $stmt->close();
        } else {
            $error = "Error al subir la imagen.";
        }
    } else {
        $error = "No se ha subido ninguna imagen.";
    }
}

// Procesar la eliminación de una rifa
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['eliminar_rifa'])) {
    $id_rifa = intval($_POST['id_rifa']);

    // Eliminar la rifa de la base de datos
    $sql = "DELETE FROM rifas_activas WHERE id = ?";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        die("Error en la preparación de la consulta: " . $conn->error);
    }
    $stmt->bind_param("i", $id_rifa);

    if ($stmt->execute()) {
        $mensaje = "Rifa eliminada con éxito.";
    } else {
        $error = "Error al eliminar la rifa: " . $stmt->error;
    }

    $stmt->close();
}

// Obtener todas las rifas activas
$sql = "SELECT id, nombre_rifa, premio, cantidad_numeros, precio_unitario, fecha_sorteo, imagen FROM rifas_activas";
$result = $conn->query($sql);

$rifas = [];
if ($result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $rifas[] = $row;
    }
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Administrar Rifas</title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="admin-container">
        <h2>Administrar Rifas</h2>
        <?php if (isset($mensaje)): ?>
            <p class="mensaje"><?php echo $mensaje; ?></p>
        <?php endif; ?>
        <?php if (isset($error)): ?>
            <p class="error"><?php echo $error; ?></p>
        <?php endif; ?>

        <!-- Formulario para crear una nueva rifa -->
        <h3>Crear Nueva Rifa</h3>
        <form method="POST" enctype="multipart/form-data"> <!-- Agregar enctype para subir archivos -->
            <label for="nombre_rifa">Nombre de la Rifa:</label>
            <input type="text" id="nombre_rifa" name="nombre_rifa" required>
            <label for="premio">Premio:</label>
            <input type="text" id="premio" name="premio" required>
            <label for="cantidad_numeros">Cantidad de Números:</label>
            <input type="number" id="cantidad_numeros" name="cantidad_numeros" required>
            <label for="precio_unitario">Precio Unitario:</label>
            <input type="number" step="0.01" id="precio_unitario" name="precio_unitario" required>
            <label for="fecha_sorteo">Fecha del Sorteo:</label>
            <input type="date" id="fecha_sorteo" name="fecha_sorteo" required>
            <label for="imagen">Imagen de la Rifa:</label>
            <input type="file" id="imagen" name="imagen" accept="image/*" required> <!-- Campo para subir la imagen -->
            <button type="submit" name="crear_rifa">Crear Rifa</button>
        </form>

        <!-- Lista de rifas existentes con opción para eliminarlas -->
        <h3>Rifas Existentes</h3>
        <table>
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Nombre</th>
                    <th>Premio</th>
                    <th>Fecha del Sorteo</th>
                    <th>Imagen</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($rifas as $rifa): ?>
                    <tr>
                        <td><?php echo $rifa['id']; ?></td>
                        <td><?php echo htmlspecialchars($rifa['nombre_rifa']); ?></td>
                        <td><?php echo htmlspecialchars($rifa['premio']); ?></td>
                        <td><?php echo htmlspecialchars($rifa['fecha_sorteo']); ?></td>
                        <td>
                            <?php if (!empty($rifa['imagen'])): ?>
                                <img src="../<?php echo $rifa['imagen']; ?>" alt="Imagen de la rifa" style="width: 100px; height: auto;">
                            <?php else: ?>
                                Sin imagen
                            <?php endif; ?>
                        </td>
                        <td>
                            <form method="POST" style="display:inline;">
                                <input type="hidden" name="id_rifa" value="<?php echo $rifa['id']; ?>">
                                <button type="submit" name="eliminar_rifa">Eliminar</button>
                            </form>
                        </td>
                    </tr>
        <?php endforeach; ?>
    </tbody>
</table>
    </div>
</body>
</html>