<?php
include '../includes/db_connect.php';

$id_rifa = isset($_GET['id_rifa']) ? intval($_GET['id_rifa']) : 0;
$numeros = isset($_GET['numeros']) ? $_GET['numeros'] : '';

if ($id_rifa === 0 || empty($numeros)) {
    die("Datos incompletos para la compra.");
}

// Definir el precio por número
$precio_por_numero = 5.00; // Puedes cambiarlo según el valor real

// Calcular total a pagar
$numeros_array = explode(',', $numeros);
$total_pagar = count($numeros_array) * $precio_por_numero;

$mensaje = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $nombre = htmlspecialchars($_POST['nombre']);
    $apellido = htmlspecialchars($_POST['apellido']);
    $cedula = htmlspecialchars($_POST['cedula']);
    $telefono = htmlspecialchars($_POST['telefono']);
    $correo = htmlspecialchars($_POST['correo']);
    $estado = 'espera'; 

    $sql = "INSERT INTO compras_rifa (id_rifa, numeros_comprados, nombre, apellido, cedula, telefono, correo, estado) 
            VALUES (?, ?, ?, ?, ?, ?, ?, ?)";

    $stmt = $conn->prepare($sql);
    if ($stmt) {
        $stmt->bind_param("isssssss", $id_rifa, $numeros, $nombre, $apellido, $cedula, $telefono, $correo, $estado);

        if ($stmt->execute()) {
            $mensaje = "Compra registrada con éxito.";
            $stmt->close();

            $whatsapp_url = "https://wa.me/+584247152322?text=" . urlencode(
                "Hola, quiero participar en la rifa. \n\n".
                "👤 Nombre: $nombre $apellido \n".
                "🆔 Cédula: $cedula \n".
                "📞 Teléfono: $telefono \n".
                "📧 Correo: $correo \n".
                "🎟️ Números elegidos: $numeros \n".
                "💰 Total a pagar: $" . number_format($total_pagar, 2)
            );

            header("Location: $whatsapp_url");
            exit();
        } else {
            $error = "Error al registrar la compra: " . $stmt->error;
        }
    } else {
        $error = "Error en la consulta: " . $conn->error;
    }
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Compra por WhatsApp</title>
    <link rel="stylesheet" href="../assets/css/style_rifa.css">
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f4f4;
            text-align: center;
            margin: 0;
            padding: 0;
        }
        .container {
            background: white;
            padding: 20px;
            width: 90%;
            max-width: 400px;
            margin: 30px auto;
            box-shadow: 0px 0px 10px rgba(0, 0, 0, 0.1);
            border-radius: 8px;
        }
        h1 {
            color: #333;
        }
        .info-box {
            background: #eee;
            padding: 15px;
            border-radius: 5px;
            margin-bottom: 15px;
            font-weight: bold;
        }
        label {
            display: block;
            text-align: left;
            margin-top: 10px;
            font-weight: bold;
        }
        input {
            width: 100%;
            padding: 8px;
            margin-top: 5px;
            border: 1px solid #ccc;
            border-radius: 5px;
        }
        .btn {
            display: inline-block;
            width: 100%;
            background: #28a745;
            color: white;
            padding: 10px;
            margin-top: 15px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
        }
        .btn:hover {
            background: #218838;
        }
        .alert {
            padding: 10px;
            margin-bottom: 10px;
            border-radius: 5px;
        }
        .alert-success {
            background: #d4edda;
            color: #155724;
        }
        .alert-danger {
            background: #f8d7da;
            color: #721c24;
        }
    </style>
</head>
<body>

    <div class="container">
        <h1>Compra por WhatsApp</h1>

        <div class="info-box">
            <p>🎟️ <strong>Números seleccionados:</strong> <?php echo $numeros; ?></p>
            <p>💰 <strong>Total a pagar:</strong> $<?php echo number_format($total_pagar, 2); ?></p>
        </div>

        <?php if ($mensaje): ?>
            <div class="alert alert-success"><?php echo $mensaje; ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo $error; ?></div>
        <?php endif; ?>

        <form action="" method="POST">
            <label for="nombre">Nombre:</label>
            <input type="text" id="nombre" name="nombre" required>

            <label for="apellido">Apellido:</label>
            <input type="text" id="apellido" name="apellido" required>

            <label for="cedula">Cédula:</label>
            <input type="text" id="cedula" name="cedula" required>

            <label for="telefono">Teléfono:</label>
            <input type="text" id="telefono" name="telefono" required>

            <label for="correo">Correo:</label>
            <input type="email" id="correo" name="correo" required>

            <button type="submit" class="btn">Enviar y continuar con WhatsApp</button>
        </form>
    </div>

</body>
</html>
