<?php
include '../includes/db_connect.php';

// Obtener el ID de la rifa y los números seleccionados desde la URL
$id_rifa = isset($_GET['id_rifa']) ? intval($_GET['id_rifa']) : 0;
$numeros_seleccionados = isset($_GET['numeros']) ? $_GET['numeros'] : '';

if ($id_rifa === 0 || empty($numeros_seleccionados)) {
    die("Rifa o números no especificados.");
}

// Consulta para obtener los detalles de la rifa activa
$sqlRifa = "SELECT nombre_rifa, premio, cantidad_numeros, precio_unitario, fecha_sorteo 
            FROM rifas_activas 
            WHERE id = ?";
$stmtRifa = $conn->prepare($sqlRifa);
$stmtRifa->bind_param("i", $id_rifa);
$stmtRifa->execute();
$resultRifa = $stmtRifa->get_result();

if ($resultRifa->num_rows === 0) {
    die("Rifa no encontrada.");
}

$rowRifa = $resultRifa->fetch_assoc();
$nombre_rifa = $rowRifa['nombre_rifa'];
$premio_principal = $rowRifa['premio'];
$cantidad_numeros = $rowRifa['cantidad_numeros'];
$precio_unitario = $rowRifa['precio_unitario'];
$fecha_sorteo = $rowRifa['fecha_sorteo'];

$conn->close();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pago Online - <?php echo htmlspecialchars($nombre_rifa); ?></title>
    <link rel="stylesheet" href="../assets/css/style_rifa.css">
    <style>
        .container {
            display: flex;
            justify-content: space-between;
        }
        .info-pago {
            width: 30%;
            padding: 20px;
            background-color: #f9f9f9;
            border: 1px solid #ddd;
        }
        .formulario-pago {
            width: 65%;
        }
        .formulario-pago input, .formulario-pago select, .formulario-pago textarea {
            width: 100%;
            padding: 10px;
            margin: 10px 0;
            border: 1px solid #ddd;
        }
        .formulario-pago button {
            padding: 10px 20px;
            background-color: #28a745;
            color: white;
            border: none;
            cursor: pointer;
        }
        .comprobante-option {
            display: none;
        }
    </style>
    <script>
        function toggleComprobante() {
            const tipoComprobante = document.getElementById('tipo_comprobante').value;
            const fotoComprobante = document.getElementById('foto_comprobante');
            const referenciaComprobante = document.getElementById('referencia_comprobante');

            if (tipoComprobante === 'foto') {
                fotoComprobante.style.display = 'block';
                referenciaComprobante.style.display = 'none';
            } else if (tipoComprobante === 'referencia') {
                fotoComprobante.style.display = 'none';
                referenciaComprobante.style.display = 'block';
            }
        }
    </script>
</head>
<body>
    <div class="container">
        <div class="info-pago">
            <h2>Información de Pago</h2>
            <p><strong>Binance:</strong> marcante91@gmail.com</p>
            <p><strong>Pago Móvil:</strong></p>
            <p>Marco Antonio Ramirez Rojas</p>
            <p>Cédula: 28839155</p>
            <p>Banco De Venezuela</p>
            <p>Celular: 0424712322</p>
            <p><strong>Total a Pagar:</strong> <?php echo count(explode(',', $numeros_seleccionados)) * $precio_unitario; ?> BGV</p>
        </div>
        <div class="formulario-pago">
            <h2>Formulario de Pago</h2>
            <form action="procesar_pago.php" method="post" enctype="multipart/form-data">
                <input type="hidden" name="id_rifa" value="<?php echo $id_rifa; ?>">
                <input type="hidden" name="numeros_seleccionados" value="<?php echo $numeros_seleccionados; ?>">
                
                <label for="nombre">Nombre:</label>
                <input type="text" name="nombre" id="nombre" required>
                
                <label for="apellido">Apellido:</label>
                <input type="text" name="apellido" id="apellido" required>
                
                <label for="cedula">Cédula:</label>
                <input type="text" name="cedula" id="cedula" required>
                
                <label for="telefono">Teléfono:</label>
                <input type="text" name="telefono" id="telefono" required>
                
                <label for="correo">Correo Electrónico:</label>
                <input type="email" name="correo" id="correo" required>
                
                <label for="metodo_pago">Método de Pago:</label>
                <select name="metodo_pago" id="metodo_pago">
                    <option value="binance">Binance</option>
                    <option value="pago_movil">Pago Móvil</option>
                </select>
                
                <label for="tipo_comprobante">Tipo de Comprobante:</label>
                <select name="tipo_comprobante" id="tipo_comprobante" onchange="toggleComprobante()">
                    <option value="foto">Subir Foto</option>
                    <option value="referencia">Número de Referencia</option>
                </select>
                
                <div id="foto_comprobante" class="comprobante-option">
                    <label for="custom_name">Nombre personalizado para el comprobante:</label>
                    <input type="text" name="custom_name" id="custom_name" placeholder="Ej: Comprobante_Usuario">
                    
                    <label for="comprobante">Subir Comprobante (Imagen):</label>
                    <input type="file" name="comprobante" id="comprobante">
                </div>
                
                <div id="referencia_comprobante" class="comprobante-option" style="display: none;">
                    <label for="referencia">Número de Referencia:</label>
                    <input type="text" name="referencia" id="referencia">
                </div>
                
                <button type="submit">Enviar Pago</button>
            </form>
        </div>
    </div>
</body>
</html>