<?php
include '../includes/db_connect.php';

// Obtener el ID de la rifa desde la URL
$id_rifa = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($id_rifa === 0) {
    die("Rifa no especificada.");
}

// Consulta para obtener los detalles de la rifa activa
$sqlRifa = "SELECT nombre_rifa, premio, cantidad_numeros, precio_unitario, fecha_sorteo 
            FROM rifas_activas 
            WHERE id = ?";
$stmtRifa = $conn->prepare($sqlRifa);
$stmtRifa->bind_param("i", $id_rifa);
$stmtRifa->execute();
$resultRifa = $stmtRifa->get_result();

if ($resultRifa->num_rows === 0) {
    die("Rifa no encontrada.");
}

$rowRifa = $resultRifa->fetch_assoc();
$nombre_rifa = $rowRifa['nombre_rifa'];
$premio_principal = $rowRifa['premio'];
$cantidad_numeros = $rowRifa['cantidad_numeros'];
$precio_unitario = $rowRifa['precio_unitario'];
$fecha_sorteo = $rowRifa['fecha_sorteo'];

// Consulta para obtener los números ocupados (incluyendo confirmados)
$sql = "SELECT numeros_comprados FROM compras_rifa WHERE id_rifa = ? AND estado IN ('espera', 'confirmado')";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $id_rifa);
$stmt->execute();
$result = $stmt->get_result();

$numeros_ocupados = [];
while ($row = $result->fetch_assoc()) {
    $numeros = explode(",", $row["numeros_comprados"]);
    $numeros_ocupados = array_merge($numeros_ocupados, $numeros);
}

$conn->close();
$numeros_ocupados_json = json_encode($numeros_ocupados);
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($nombre_rifa); ?></title>
    <link rel="stylesheet" href="../assets/css/style_rifa.css">
</head>
<body>
    <div class="container">
        <h1><?php echo htmlspecialchars($nombre_rifa); ?></h1>
        <h2>GRAN SORTEO</h2>
        <div class="premio pulse">¡GÁNATE UN <?php echo htmlspecialchars($premio_principal); ?>!</div>
        <div class="precio">Precio por número: $<?php echo htmlspecialchars($precio_unitario); ?></div>

        <div class="tablero">
            <?php
            for ($i = 1; $i <= $cantidad_numeros; $i++) {
                $numero = str_pad($i, 2, '0', STR_PAD_LEFT);
                echo "<div class='numero' data-numero='$numero'>$numero</div>";
            }
            ?>
        </div>

        <div class="carrito">
            <h3>🛒 Carrito de Números</h3>
            <ul id="lista-carrito"></ul>
            <p id="total-precio">Total: $0</p>
        </div>
        <div class="fecha-sorteo">SORTEO EL <?php echo htmlspecialchars($fecha_sorteo); ?> A LAS 11 AM - LOTERÍA NACIONAL</div>

        <div class="formulario-pago">
            <h3>Seleccione el método de pago</h3>
            <button onclick="pagarEnPagina()">Pagar en la Página</button>
            <button class="whatsapp" onclick="pagarPorWhatsApp()">Pagar por WhatsApp</button>
        </div>
    </div>

    <script>
    let numerosSeleccionados = [];
    let numerosOcupados = <?php echo $numeros_ocupados_json; ?>;
    let precioUnitario = <?php echo $precio_unitario; ?>;

    document.addEventListener("DOMContentLoaded", function () {
        document.querySelectorAll('.numero').forEach(numero => {
            let num = numero.getAttribute('data-numero');
            
            // Marcar números ocupados
            if (numerosOcupados.includes(num)) {
                numero.classList.add('ocupado');
                numero.style.pointerEvents = 'none'; // Deshabilitar clic
            } else {
                // Permitir selección solo si el número no está ocupado
                numero.addEventListener('click', () => {
                    if (numerosSeleccionados.includes(num)) {
                        numerosSeleccionados = numerosSeleccionados.filter(n => n !== num);
                        numero.classList.remove('seleccionado');
                    } else {
                        numerosSeleccionados.push(num);
                        numero.classList.add('seleccionado');
                    }
                    actualizarCarrito();
                });
            }
        });
    });

    function actualizarCarrito() {
        const listaCarrito = document.getElementById('lista-carrito');
        listaCarrito.innerHTML = '';
        let precioTotal = 0;

        numerosSeleccionados.forEach(numero => {
            const li = document.createElement('li');
            li.textContent = `Número: ${numero} - Precio: $${precioUnitario}`;
            listaCarrito.appendChild(li);
            precioTotal += precioUnitario;
        });

        document.getElementById('total-precio').textContent = `Total: $${precioTotal}`;
    }

    function pagarEnPagina() {
        if (numerosSeleccionados.length === 0) {
            alert("Debe seleccionar al menos un número.");
            return;
        }
        window.location.href = `../pages/pago_online.php?id_rifa=<?php echo $id_rifa; ?>&numeros=${numerosSeleccionados.join(',')}`;
    }

    function pagarPorWhatsApp() {
    if (numerosSeleccionados.length === 0) {
        alert("Debe seleccionar al menos un número.");
        return;
    }
    window.location.href = `../pages/compra_whatsapp.php?id_rifa=<?php echo $id_rifa; ?>&numeros=${numerosSeleccionados.join(',')}`;
}


    </script>
    <style>
        .ocupado {
            background-color: red !important;
            cursor: not-allowed;
        }
        .seleccionado {
            background-color: yellow !important;
        }
    </style>
</body>
</html>