<?php
include '../includes/db_connect.php';

// Consulta para obtener el nombre de la rifa activa
$sqlRifa = "SELECT nombre_rifa FROM rifas_activas LIMIT 1"; // Ajusta la consulta si hay más de una rifa activa
$resultRifa = $conn->query($sqlRifa);

$nombre_rifa = "RIFA"; // Valor por defecto
if ($resultRifa->num_rows > 0) {
    $rowRifa = $resultRifa->fetch_assoc();
    $nombre_rifa = $rowRifa['nombre_rifa'];
}

// Consulta para obtener la cantidad de números y el precio unitario de la tabla rifas_activas
$sqlCantidad = "SELECT cantidad_numeros, precio_unitario FROM rifas_activas LIMIT 1";
$resultCantidad = $conn->query($sqlCantidad);
$cantidad_numeros = 100; // Valor por defecto en caso de que no se obtenga de la base de datos
$precio_unitario = 0; // Valor por defecto en caso de que no se obtenga de la base de datos

if ($resultCantidad->num_rows > 0) {
    $rowCantidad = $resultCantidad->fetch_assoc();
    $cantidad_numeros = $rowCantidad['cantidad_numeros'];
    $precio_unitario = $rowCantidad['precio_unitario'];
}

// Consulta para obtener los números ocupados
$sql = "SELECT numeros_comprados FROM compras_rifa WHERE estado IN ('espera', 'confirmado')";
$result = $conn->query($sql);

$numeros_ocupados = [];
while ($row = $result->fetch_assoc()) {
    $numeros = explode(",", $row["numeros_comprados"]);
    $numeros_ocupados = array_merge($numeros_ocupados, $numeros);
}

$conn->close();
$numeros_ocupados_json = json_encode($numeros_ocupados);
?><!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gran Sorteo</title>
    <link rel="stylesheet" href="../assets/css/style_rifa.css">
</head>
<body>
    <div class="container">
        <h1><?php echo htmlspecialchars($nombre_rifa); ?></h1> <!-- Aquí se muestra el nombre de la rifa -->
        <h2>GRAN SORTEO</h2>
        <div class="premio pulse">¡GÁNATE UN Avión!</div>
        <div class="precio"></div>

        <div class="tablero">
            <?php
            for ($i = 1; $i <= $cantidad_numeros; $i++) {
                $numero = str_pad($i, 2, '0', STR_PAD_LEFT);
                echo "<div class='numero' data-numero='$numero'>$numero</div>";
            }
            ?>
        </div>

        <div class="carrito">
            <h3>🛒 Carrito de Números</h3>
            <ul id="lista-carrito"></ul>
            <p id="total-precio">Total: $0</p>
        </div>
        <div class="fecha-sorteo">SORTEO EL 10/12 A LAS 11 AM - LOTERÍA NACIONAL</div>

        <div class="formulario-pago">
            <h3>Datos de Pago</h3>
            <form id="form-pago">
                <label for="nombre">Nombre:</label>
                <input type="text" id="nombre" name="nombre" required>

                <label for="apellido">Apellido:</label>
                <input type="text" id="apellido" name="apellido" required>

                <label for="cedula">Cédula:</label>
                <input type="text" id="cedula" name="cedula" required>

                <label for="telefono">Teléfono:</label>
                <input type="text" id="telefono" name="telefono" required>

                <label for="correo">Correo Electrónico:</label>
                <input type="email" id="correo" name="correo" required>

                <input type="hidden" id="metodo_pago" name="metodo_pago">

                <button type="submit" onclick="document.getElementById('metodo_pago').value = 'pagina'">Pagar en la Página</button>
                <button type="button" class="whatsapp" onclick="pagarPorWhatsApp()">Pagar por WhatsApp</button>
            </form>
        </div>
    </div>

    <script>
    let numerosSeleccionados = [];
    let numerosOcupados = <?php echo $numeros_ocupados_json; ?>;
    let precioUnitario = <?php echo $precio_unitario; ?>;

    document.addEventListener("DOMContentLoaded", function () {
        document.querySelectorAll('.numero').forEach(numero => {
            let num = numero.getAttribute('data-numero');
            
            if (numerosOcupados.includes(num)) {
                numero.classList.add('ocupado');
                numero.style.pointerEvents = 'none';
            }

            numero.addEventListener('click', () => {
                if (numerosSeleccionados.includes(num)) {
                    // Si ya está seleccionado, lo quitamos
                    numerosSeleccionados = numerosSeleccionados.filter(n => n !== num);
                    numero.classList.remove('seleccionado');
                } else {
                    // Si no está seleccionado, lo agregamos
                    numerosSeleccionados.push(num);
                    numero.classList.add('seleccionado');
                }
                actualizarCarrito();
            });
        });
    });

    function actualizarCarrito() {
        const listaCarrito = document.getElementById('lista-carrito');
        listaCarrito.innerHTML = '';

        let precioTotal = 0;
        numerosSeleccionados.forEach(numero => {
            const li = document.createElement('li');
            li.textContent = `Número: ${numero} - Precio: $${precioUnitario}`;

            const botonEliminar = document.createElement('button');
            botonEliminar.textContent = 'Eliminar';
            botonEliminar.onclick = () => eliminarDelCarrito(numero);

            li.appendChild(botonEliminar);
            listaCarrito.appendChild(li);

            precioTotal += precioUnitario;
        });

        document.getElementById('total-precio').textContent = `Total: $${precioTotal}`;
    }

    function eliminarDelCarrito(numero) {
        numerosSeleccionados = numerosSeleccionados.filter(n => n !== numero);
        document.querySelector(`.numero[data-numero="${numero}"]`).classList.remove('seleccionado');
        actualizarCarrito();
    }

    document.getElementById('form-pago').addEventListener('submit', function(event) {
        event.preventDefault();

        const nombre = document.getElementById('nombre').value;
        const apellido = document.getElementById('apellido').value;
        const cedula = document.getElementById('cedula').value;
        const telefono = document.getElementById('telefono').value;
        const correo = document.getElementById('correo').value;
        const numeros = numerosSeleccionados.join(',');

        if (numeros.length === 0) {
            alert("Debe seleccionar al menos un número.");
            return;
        }

        const formData = new FormData();
        formData.append("nombre", nombre);
        formData.append("apellido", apellido);
        formData.append("cedula", cedula);
        formData.append("telefono", telefono);
        formData.append("correo", correo);
        formData.append("numeros_comprados", numeros);
        formData.append("metodo_pago", "pagina");

        fetch('procesar_compra.php', {
            method: 'POST',
            body: formData
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                alert("Pago registrado con éxito.");
                window.location.reload();
            } else {
                alert("Error al procesar la compra.");
            }
        })
        .catch(error => console.error("Error:", error));
    });

    function pagarPorWhatsApp() {
    const nombre = document.getElementById('nombre').value;
    const apellido = document.getElementById('apellido').value;
    const cedula = document.getElementById('cedula').value;
    const telefono = document.getElementById('telefono').value;
    const correo = document.getElementById('correo').value;
    const numeros = numerosSeleccionados.join(', ');

    if (numeros.length === 0) {
        alert("Debe seleccionar al menos un número.");
        return;
    }

    // Obtener el valor del <h1>
    const nombreRifa = document.querySelector('h1').textContent;

    // Calcular el precio total
    const precioTotal = numerosSeleccionados.length * precioUnitario;

    // Crear el mensaje con el formato deseado
    const mensaje = `Hola, estoy interesado/a en la rifa: "${nombreRifa}".\n\nQuiero pagar por los siguientes números: ${numeros}.\nPrecio total: $${precioTotal}.\n\nMis datos son:\nNombre: ${nombre} ${apellido}\nCédula: ${cedula}\nTeléfono: ${telefono}\nCorreo: ${correo}`;

    // Codificar el mensaje para la URL de WhatsApp
    const urlWhatsApp = `https://wa.me/+584247152322?text=${encodeURIComponent(mensaje)}`;

    // Enviar los datos al servidor (opcional, si necesitas registrar la compra)
    const formData = new FormData();
    formData.append("nombre", nombre);
    formData.append("apellido", apellido);
    formData.append("cedula", cedula);
    formData.append("telefono", telefono);
    formData.append("correo", correo);
    formData.append("numeros_comprados", numeros);
    formData.append("metodo_pago", "whatsapp");

    fetch('procesar_compra.php', {
        method: 'POST',
        body: formData
    })
    .then(response => response.json())
    .then(() => {
        // Abrir WhatsApp en una nueva pestaña
        window.open(urlWhatsApp, '_blank');
    })
    .catch(error => console.error("Error:", error));
}    </script>
    <style>
        .ocupado {
            background-color: red !important;
            cursor: not-allowed;
        }
    </style>
</body>
</html>